from typing import Literal

Whitespace = Literal[
    'normal',
    'nowrap',
    'pre',
    'pre-line',
    'pre-wrap',
    'break-spaces',
]
